#
# spec file for package python-pytools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytools
Version:        2024.1.5
Release:        1.3
Summary:        A collection of tools for Python
License:        MIT
URL:            https://pypi.python.org/pypi/pytools
Source0:        https://files.pythonhosted.org/packages/source/p/pytools/pytools-%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module numpy >= 1.6.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module platformdirs >= 2.2.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sqlite3}
BuildRequires:  %{python_module typing_extensions if %python-base < 3.11}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.6.0
Requires:       python-platformdirs
%if %{python_version_nodots} < 311
Requires:       python-typing_extensions
%endif
BuildArch:      noarch
%python_subpackages

%description
Pytools is a big bag of things that are "missing" from the Python standard library.
This is mainly a dependency of other software packages (pycuda, pyopencl, etc ),
and is probably of little interest to you unless you use those. If you're curious
nonetheless, here's what's on offer:
* A ton of small tool functions such as len_iterable, argmin, tuple generation,
  permutation generation, ASCII table pretty printing, GvR's mokeypatch_xxx() hack,
  the elusive flatten, and much more.
* Michele Simionato's decorator module
* A time-series logging module, pytools.log.
* Batch job submission, pytools.batchjob.
* A lexer, pytools.lex.

%prep
%setup -q -n pytools-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/pytools
%{python_sitelib}/pytools-%{version}*-info

%changelog
* Mon Jun 24 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.5:
  * PersistentDict: allow setting sync
  * PersistentDict: smarter WOPD store
  * PersistentDict: concurrency improvements
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.4:
  * remove get_read_from_map_from_permutation,
    get_write_to_map_from_permutation
  * KeyBuilder: support function hashing
  * PersistentDict: Use sqlite as backend storage v2
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.2:
  * WriteOncePersistentDict: use functools.lru_cache
  * PersistentDict: better docs, type annotations
  * clean up some version_info checks
* Thu Mar 21 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.1:
  * move tests under package directory
  * PersistentDict: support frozendict, immutabledict, FrozenOrderedSet
  * Tag: implement eq, repr for DottedName
  * persistent_dict: separate different sources of KeyErrors
  * KeyBuilder: allow hashing of classes w/ update_persistent_hash
  * PersistentDict: replace _make_dir_recursively
* Fri Jan 26 2024 Dirk Müller <dmueller@suse.com>
- update to 2023.1.1:
  * enable isort
  * refdebug: concatenate tuple with tuple
  * typedump: type improvements
  * docs: update intersphinx mapping from deprecated variant
  * Fix persistent numpy dtype hashing for numpy 1.25
  * Remove persistent_dict.new_hash for real
  * Support attrs classes for persistent hashing
  * Avoid a reference cycle in ProcessLogger
  * Add WriteOncePersistentDict.clear_in_mem_cache
* Tue Feb 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- update to 2022.1.14:
  * add get_graph_dot_code and show_dot (#151)
  * Make GraphT a parametric type alias
  * graph: create GraphT (#166)
  * graph: add is_connected (#163)
  * graph-doc: change CycleError to autoexception
  * add pytest_raises_on_rank (#162)
- v2022.1.13
  * Move Py compat target to 3.8 (closes gh-160)
  * graph: more mypy annotations
  * graph: small fixes
  * convergence: small mypy fixes (#157)
  * Add validate_graph (#155)
  * Add reverse_graph
  * Stop using Self type for the moment
  * add strtobool() (#150)
  * Bump versions of various github actions components
  * UniqueNameGenerator: add documentation (#102)
- v2022.1.12
  * Fix type annotation of Record-ish.__slots__; it's a ClassVar
  * pdict: When building dataclass hash, include type
- v2022.1.11
  * pdict: Test support for enums and dataclasses
  * pdict: Support dataclasses
  * pdict: allow caching key on frozen instances
  * persistent_dict: simplify logic using getattr()
- v2022.1.10
  * Support Enum values in PersistentDict
  * use ParamSpec to annotate memoization decorators
  * Install numpy for pylint runs after hard numpy dep drop
- v2022.1.9
  * Drop deprecated memoize_method_with_uncached, fix test
  * Remove deprecated use of Taggable.copy in test_tag
  * Make numpy dependency optional
  * Fix deprecated reference to np.float
  * Include CITATION.cff in releases
  * Fix CITATION.cff, add validation CI
- v2022.1.8
  * add IgnoredForEqualityTag (#134)
  * Complete author list in CITATION.cff
  * Add Zenodo badge, citation info
- v2022.1.7
  * UniqueNameGenerator.add_name(s?): new argument `existing_ok`
- v2022.1.6
  * Record.__eq__: early exit for identical instances
- v2022.1.5
  * Tighten typing_extensions version requirement
  * ImmutableRecordWithoutPickling.__hash__: tolerate _cached_hash attr disappearing
- v2022.1.4
  * Fix type annotation of Taggable.tags_of_type
  * use math.perm and math.comb if available
- v2022.1.3
  * Fix type names in pytools.tag
  * Placate flake8-bugbear B020
  * Drop curl insecure (-k) flags from CI, switch ci-support URLs
  * Downstream CI: use ci-support, add Gitlab
- v2022.1.2
  * PersistentDict: add generic KeyBuilder.update_for_type
- v2022.1.1
  * Taggable: Do not force copy for tag setting
  * restrucurte lock file timeout
* Tue Feb 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2022.1:
  * use platformdirs
  * add typing to memoize_in
  * type annotations
* Mon Apr 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2021.2.3:
  * Support pytools.tag in persistent_dict
  * Add a backport of pkgutil.resolve_name
  * Add persistent_dict.KeyBuilder.new_hash for hash alg customization
  * Use unordered_hash in KeyBuilder hashing frozenset
  * Drop dependency on, included obsolete copy of 'decorator' pypi module
  * make obj_array_vectorize work on class methods
- Don't build for Python 3.6, due to no NumPy.
- Remove decorator from {Build,}Requires
* Sat Jan 23 2021 Dirk Müller <dmueller@suse.com>
- update to 2021.1:
  * pytools.tag.Taggable added
* Sun Dec 20 2020 Benjamin Greiner <code@bnavigator.de>
- Update requirements
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 2020.4.4:
  * pytools.codegen added
* Mon Aug  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2020.3.1
  * drop Python2 support
  * Drop 3.4, 3.5 support
  * Work around numpy/numpy#16564 in make_obj_array
  * add CycleError class
  * add few procedures
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Make requires to really be the requires
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 2020.1
  + No upstream changelog available
* Tue May 14 2019 John Jolly <jjolly@suse.com>
- Update to version 2019.1.1
  + No upstream changelog available
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jul  9 2018 mpluskal@suse.com
-  Update to version 2018.5.2
  * No changelog available
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 2018.2
  * No changelog available
* Tue Oct 17 2017 mpluskal@suse.com
- Update to version 2017.6
  * No changelog available
* Sun Jun 11 2017 mpluskal@suse.com
- Update to version 2017.3
  * No changelog available
* Sat Mar  4 2017 mpluskal@suse.com
- Update to version 2016.2.6
  * No changelog available
- Convert to python singlespec
* Thu Feb  4 2016 mpluskal@suse.com
- Update to 2016.1
  * No changelog available
- Update dependencies
* Tue Dec  8 2015 mpluskal@suse.com
- Install license
* Mon Dec  7 2015 mpluskal@suse.com
- Update to 2015.1.6
  * No changelog available
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 2013.5.7
  + No changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu May  2 2013 speilicke@suse.com
- Fix dependencies
- Run testsuite
- Package README
* Wed May  1 2013 prusnak@opensuse.org
- updated to 2012.1
* Sun Jun 17 2012 scorot@free.fr
- version 2011.5
  * no changelog available
* Wed Jun 13 2012 scorot@free.fr
- spec file cleanup
* Mon Jun  4 2012 scorot@free.fr
- spec file cleanup and re-formating
